InvocationRunnerFn

Type Alias InvocationRunnerFn 

pub type InvocationRunnerFn = fn(&mut Editor, CommandInvocation) -> bool;
lattice_mode::Mode::invocation_runner returns Some(id). Returns true when the runner claimed the invocation, false when [Editor::run_invocation] should fall through to the grammar Action gate / run_document_invocation for central dispatch.