render_tutor_headerline

Function render_tutor_headerline 

pub fn render_tutor_headerline(s: &TutorViewState) -> Option<HeaderlineRow>
Render function for SimpleHeaderlineHandle<TutorViewState>.

Converts the current session spans into cells and returns a HeaderlineRow with the tutor’s retro background, or None when there is nothing to display yet.